import { Class, ClassReflection, ConstructorReflection, MethodReflection, ParameterPropertyReflection, ParameterReflection, PropertyReflection, Reflection } from "./types";
declare type TypedReflection = ClassReflection | MethodReflection | PropertyReflection | ParameterReflection | ConstructorReflection | ParameterPropertyReflection;
declare type WalkVisitor = (value: TypedReflection, ctx: WalkMemberContext) => TypedReflection | undefined;
interface WalkMemberContext {
    target: Class;
    classPath: Class[];
    parent: Reflection;
    visitor: WalkVisitor;
}
interface WalkClassContext {
    visitor: WalkVisitor;
    classPath: Class[];
}
declare class GenericMap {
    private maps;
    constructor(types: Class[]);
    private createMaps;
    private getTemplates;
    private getTypes;
    get(rawType: string | string[]): Class<any> | Class<any>[];
}
declare namespace visitors {
    function addsDesignTypes(meta: TypedReflection, ctx: WalkMemberContext): TypedReflection;
    function addsDecorators(meta: TypedReflection, ctx: WalkMemberContext): TypedReflection;
    function addsTypeOverridden(meta: TypedReflection, ctx: WalkMemberContext): TypedReflection;
    function addsGenericOverridden(meta: TypedReflection, ctx: WalkMemberContext): TypedReflection;
    function addsTypeClassification(meta: TypedReflection, ctx: WalkMemberContext): TypedReflection | undefined;
    function addsParameterProperties(meta: TypedReflection, ctx: WalkMemberContext): TypedReflection | undefined;
    function removeIgnored(meta: TypedReflection, ctx: WalkMemberContext): TypedReflection | undefined;
}
/**
 * Walk into type super class
 * @param type type to reflect
 */
declare function walkClass(type: Class, ctx: WalkClassContext): ClassReflection;
export { walkClass, visitors, WalkVisitor, GenericMap };
